<?php

/**
 * @file
 * Contains \Drupal\filelist_formatter\Plugin\field\formatter\FileListFormatter.
 *
 * @author keopx
 */

namespace Drupal\filelist_formatter\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'filelist_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "filelist_formatter",
 *   label = @Translation("List"),
 *   field_types = {
 *     "file"
 *   }
 * )
 */
class FileListFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items) {
    $elements = array();
    if (!$items->isEmpty()) {
      foreach ($items as $delta => $item) {
        if ($item->isDisplayed() && $item->entity) {
          $elements[$delta] = array(
            '#theme' => 'file_link',
            '#file' => $item->entity,
            '#description' => $item->description,
          );
          // Pass field item attributes to the theme function.
          if (isset($item->_attributes)) {
            $elements[$delta] += array('#attributes' => array());
            $elements[$delta]['#attributes'] += $item->_attributes;
            // Unset field item attributes since they have been included in the
            // formatter output and should not be rendered in the field template.
            unset($item->_attributes);
          }
        }
      }

      $elements = array(
        '#theme' => 'item_list',
        '#items' => $elements,
        '#list_type' => 'ol',
      );
    }

    return $elements;
  }

}
